#!/usr/bin/env node
"use strict";
var __values = (this && this.__values) || function (o) {
    var m = typeof Symbol === "function" && o[Symbol.iterator], i = 0;
    if (m) return m.call(o);
    return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
};
Object.defineProperty(exports, "__esModule", { value: true });
var program = require("commander");
require('colors');
var version = require('../package').version;
var firstArg = undefined;
var secondArg = undefined;
function list(val) {
    return val.split(',');
}
program
    .version(version)
    .arguments('<cmd> <file>')
    .option('-p, --parameters <items>', 'List of params', list)
    .option('-p, --pseudo <items>', 'List of pseudo overrides', list)
    .option('-G, --no-guess-parameters', 'Fail validation if a parameter with no Default is not passed')
    .option('-g, --only-guess-parameters <items>', 'Guess the provided parameters, and fail validation if a parameter with no Default is passed', list)
    .action(function (arg1, arg2) {
    firstArg = arg1;
    secondArg = arg2;
});
program.parse(process.argv);
if (typeof firstArg === 'undefined') {
    console.error('no command given!');
    process.exit(1);
}
if (firstArg == "validate") {
    var validator = require('./validator');
    if (program.parameters) {
        try {
            for (var _a = __values(program.parameters), _b = _a.next(); !_b.done; _b = _a.next()) {
                var param = _b.value;
                // Set the parameter
                var kv = param.split('=');
                validator.addParameterValue(kv[0], kv[1]);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_1) throw e_1.error; }
        }
    }
    if (program.pseudo) {
        try {
            for (var _d = __values(program.pseudo), _e = _d.next(); !_e.done; _e = _d.next()) {
                var pseudo = _e.value;
                // Set the parameter
                var kv = pseudo.split('=');
                validator.addPseudoValue(kv[0], kv[1]);
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_e && !_e.done && (_f = _d.return)) _f.call(_d);
            }
            finally { if (e_2) throw e_2.error; }
        }
    }
    var guessParameters = void 0;
    if (program.guessParameters === false) {
        guessParameters = [];
    }
    else if (program.onlyGuessParameters) {
        guessParameters = program.onlyGuessParameters;
    }
    else {
        guessParameters = undefined;
    }
    var options = {
        guessParameters: guessParameters
    };
    var result = validator.validateFile(secondArg, options);
    // Show the errors
    console.log((result['errors']['info'].length + " infos").grey);
    try {
        for (var _g = __values(result['errors']['info']), _h = _g.next(); !_h.done; _h = _g.next()) {
            var info = _h.value;
            console.log('Resource: ' + info['resource'].grey);
            console.log('Message: ' + info['message'].grey);
            console.log('Documentation: ' + info['documentation'].grey + '\n');
        }
    }
    catch (e_3_1) { e_3 = { error: e_3_1 }; }
    finally {
        try {
            if (_h && !_h.done && (_j = _g.return)) _j.call(_g);
        }
        finally { if (e_3) throw e_3.error; }
    }
    console.log((result['errors']['warn'].length + " warn").yellow);
    try {
        for (var _k = __values(result['errors']['warn']), _l = _k.next(); !_l.done; _l = _k.next()) {
            var warn = _l.value;
            console.log('Resource: ' + warn['resource'].yellow);
            console.log('Message: ' + warn['message'].yellow);
            console.log('Documentation: ' + warn['documentation'].yellow + '\n');
        }
    }
    catch (e_4_1) { e_4 = { error: e_4_1 }; }
    finally {
        try {
            if (_l && !_l.done && (_m = _k.return)) _m.call(_k);
        }
        finally { if (e_4) throw e_4.error; }
    }
    console.log((result['errors']['crit'].length + " crit").red);
    try {
        for (var _o = __values(result['errors']['crit']), _p = _o.next(); !_p.done; _p = _o.next()) {
            var crit = _p.value;
            console.log('Resource: ' + crit['resource'].red);
            console.log('Message: ' + crit['message'].red);
            console.log('Documentation: ' + crit['documentation'].red + '\n');
        }
    }
    catch (e_5_1) { e_5 = { error: e_5_1 }; }
    finally {
        try {
            if (_p && !_p.done && (_q = _o.return)) _q.call(_o);
        }
        finally { if (e_5) throw e_5.error; }
    }
    if (result['templateValid'] === false) {
        console.log('Template invalid!'.red.bold);
        process.exit(1);
    }
    else {
        console.log('Template valid!'.green);
        process.exit(0);
    }
}
else if (firstArg == "docs") {
    var docs = require('./docs');
    console.log(docs.getDoc(secondArg));
}
var e_1, _c, e_2, _f, e_3, _j, e_4, _m, e_5, _q;
//# sourceMappingURL=index.js.map